@@ -110,6 +110,8 @@ class AristaDriver(driver_api.MechanismDriver):
 
         self.provision_queue = multiprocessing.Queue()
         self.trunk_driver = None
+        self.vif_details = {portbindings.VIF_DETAILS_CONNECTIVITY:
+                            portbindings.CONNECTIVITY_L2}
 
     def initialize(self):
         self.mlag_pairs = db_lib.get_mlag_physnets()
@@ -386,8 +388,8 @@ class AristaDriver(driver_api.MechanismDriver):
                 if (segment_type == n_const.TYPE_VXLAN and self.manage_fabric):
                     if self._bind_fabric(context, segment):
                         continue
-            elif (port.get(portbindings.VNIC_TYPE)
-                    == portbindings.VNIC_BAREMETAL):
+            elif (port.get(portbindings.VNIC_TYPE) ==
+                  portbindings.VNIC_BAREMETAL):
                 if (not self.managed_physnets or
                         physnet in self.managed_physnets):
                     if self._bind_baremetal_port(context, segment):
